Welcome to uHugo’s documentation! — uHugo 1.1.10 documentation

# Welcome to uHugo’s documentation!

uHugo is a helper tool for Hugo that automates the instillation and updating of the application. It also updates static site cloud provider’s configurations if exists.

## Instillation

Make sure you are on Python 3.6+. In your terminal, type in:

    > pip install uhugo

You can test it by

    > uhugo --help

    Usage: uhugo [OPTIONS] COMMAND [ARGS]...

    uhugo is a Hugo binary helper that downloads and set ups the environment.

    Options:
    --debug    Use debug mode
    --version  Show the version and exit.
    --help     Show this message and exit.

    Commands:
    install  Install latest Hugo binary files
    update   Updates Hugo binary files and any associated configurations

Contents:

- Commands
  - Install
  - Update
- Providers
  - Supported Providers
- Reference
  - uhugo.cmd
  - uhugo.download
  - uhugo.checks
  - uhugo.install
  - uhugo.terminal_commands.__init__
  - uhugo.terminal_commands.posix
  - uhugo.terminal_commands.windows
  - uhugo.post_install.detect_providers
  - uhugo.post_install.providers.__init__
  - uhugo.post_install.providers.cloudflare
  - uhugo.post_install.providers.netlify
  - uhugo.post_install.providers.vercel

# Indices and tables

- Index

- Module Index

- Search Page